@@ -7,25 +7,33 @@ from aws_lambda_types.api_gw import APIGWPayloadV2RequestDict
 def handler(event: APIGWPayloadV2RequestDict, _):
 
     try:
-        print("REQUEST: {}".format(json.dumps(event)))
+        print("REQUEST {}".format(json.dumps(event)))
 
-        match = re.search("^\/live\/(.+)\/([^\/]+)\.(m3u8|mpd)$", event["rawPath"])
+        url = event["rawPath"]
+        if event["rawQueryString"]:
+            url += "?" + event["rawQueryString"]
 
-        print("CONFIG: {}", match.groups())
+        match = re.search("^\/live\/(.+?)(?:\/([^\/]+)\.(m3u8|mpd))?$", url)
 
-        protocol = "dash" if match.group(3) is "mpd" else "hls"
+        print("CONFIG", match.groups())
+
+        protocol = "dash" if match.group(3) == "mpd" else "hls"
         streams = streamlink.streams(match.group(1))
-        stream = streams[match.group(2)]
+        stream = streams[match.group(2) or "best"]
 
-        return {
+        result = {
             "statusCode": 302,
             "headers": {
                 "Content-Type": content_type(protocol),
                 "Location": stream.url,
             },
         }
+
+        print("RETURN", result)
+        return result
+
     except Exception as e:
-        print(e)
+        print("ERROR", e)
         return {
             "statusCode": 404,
             "body": "NOT FOUND",
